Class: Google::Apis::ManagedidentitiesV1::DenyMaintenancePeriod
- Inherits:
-
Object
- Object
- Google::Apis::ManagedidentitiesV1::DenyMaintenancePeriod
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedidentities_v1/classes.rb,
lib/google/apis/managedidentities_v1/representations.rb,
lib/google/apis/managedidentities_v1/representations.rb
Overview
DenyMaintenancePeriod definition. Maintenance is forbidden within the deny period. The start_date must be less than the end_date.
Instance Attribute Summary collapse
-
#end_date ⇒ Google::Apis::ManagedidentitiesV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#start_date ⇒ Google::Apis::ManagedidentitiesV1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#time ⇒ Google::Apis::ManagedidentitiesV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DenyMaintenancePeriod
constructor
A new instance of DenyMaintenancePeriod.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DenyMaintenancePeriod
Returns a new instance of DenyMaintenancePeriod.
405 406 407 |
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 405 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date ⇒ Google::Apis::ManagedidentitiesV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property endDate
384 385 386 |
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 384 def end_date @end_date end |
#start_date ⇒ Google::Apis::ManagedidentitiesV1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property startDate
396 397 398 |
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 396 def start_date @start_date end |
#time ⇒ Google::Apis::ManagedidentitiesV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property time
403 404 405 |
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 403 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
410 411 412 413 414 |
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 410 def update!(**args) @end_date = args[:end_date] if args.key?(:end_date) @start_date = args[:start_date] if args.key?(:start_date) @time = args[:time] if args.key?(:time) end |