Class: Google::Apis::ManagedidentitiesV1::Peering
- Inherits:
-
Object
- Object
- Google::Apis::ManagedidentitiesV1::Peering
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/managedidentities_v1/classes.rb,
lib/google/apis/managedidentities_v1/representations.rb,
lib/google/apis/managedidentities_v1/representations.rb
Overview
Represents a Managed Service for Microsoft Active Directory Peering.
Instance Attribute Summary collapse
-
#authorized_network ⇒ String
Required.
-
#create_time ⇒ String
Output only.
-
#domain_resource ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#status_message ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Peering
constructor
A new instance of Peering.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Peering
Returns a new instance of Peering.
1962 1963 1964 |
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 1962 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authorized_network ⇒ String
Required. The full names of the Google Compute Engine networks to which the instance is connected. Caller
needs to make sure that CIDR subnets do not overlap between networks, else
peering creation will fail.
Corresponds to the JSON property authorizedNetwork
1920 1921 1922 |
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 1920 def @authorized_network end |
#create_time ⇒ String
Output only. The time the instance was created.
Corresponds to the JSON property createTime
1925 1926 1927 |
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 1925 def create_time @create_time end |
#domain_resource ⇒ String
Required. Full domain resource path for the Managed AD Domain involved in
peering. The resource path should be in the form: projects/project_id/
locations/global/domains/domain_name`
Corresponds to the JSON propertydomainResource`
1932 1933 1934 |
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 1932 def domain_resource @domain_resource end |
#labels ⇒ Hash<String,String>
Optional. Resource labels to represent user-provided metadata.
Corresponds to the JSON property labels
1937 1938 1939 |
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 1937 def labels @labels end |
#name ⇒ String
Output only. Unique name of the peering in this scope including projects and
location using the form: projects/project_id/locations/global/peerings/
peering_id`.
Corresponds to the JSON propertyname`
1944 1945 1946 |
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 1944 def name @name end |
#state ⇒ String
Output only. The current state of this Peering.
Corresponds to the JSON property state
1949 1950 1951 |
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 1949 def state @state end |
#status_message ⇒ String
Output only. Additional information about the current status of this peering,
if available.
Corresponds to the JSON property statusMessage
1955 1956 1957 |
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 1955 def @status_message end |
#update_time ⇒ String
Output only. Last update time.
Corresponds to the JSON property updateTime
1960 1961 1962 |
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 1960 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 |
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 1967 def update!(**args) @authorized_network = args[:authorized_network] if args.key?(:authorized_network) @create_time = args[:create_time] if args.key?(:create_time) @domain_resource = args[:domain_resource] if args.key?(:domain_resource) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @status_message = args[:status_message] if args.key?(:status_message) @update_time = args[:update_time] if args.key?(:update_time) end |