Class: Google::Apis::ManagedidentitiesV1::Schedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedidentities_v1/classes.rb,
lib/google/apis/managedidentities_v1/representations.rb,
lib/google/apis/managedidentities_v1/representations.rb

Overview

Configure the schedule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Schedule

Returns a new instance of Schedule.



2167
2168
2169
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2167

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayString

Allows to define schedule that runs specified day of the week. Corresponds to the JSON property day

Returns:

  • (String)


2153
2154
2155
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2153

def day
  @day
end

#durationString

Output only. Duration of the time window, set by service producer. Corresponds to the JSON property duration

Returns:

  • (String)


2158
2159
2160
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2158

def duration
  @duration
end

#start_timeGoogle::Apis::ManagedidentitiesV1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



2165
2166
2167
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2165

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2172
2173
2174
2175
2176
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2172

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @duration = args[:duration] if args.key?(:duration)
  @start_time = args[:start_time] if args.key?(:start_time)
end