Class: Google::Apis::ManagedidentitiesV1::TrustProp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedidentities_v1/classes.rb,
lib/google/apis/managedidentities_v1/representations.rb,
lib/google/apis/managedidentities_v1/representations.rb

Overview

Represents a relationship between two domains. This allows a controller in one domain to authenticate a user in another domain. If the trust is being changed, it will be placed into the UPDATING state, which indicates that the resource is being reconciled. At this point, Get will reflect an intermediate state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TrustProp

Returns a new instance of TrustProp.



2462
2463
2464
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the instance was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2402
2403
2404
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2402

def create_time
  @create_time
end

#last_trust_heartbeat_timeString

Output only. The last heartbeat time when the trust was known to be connected. Corresponds to the JSON property lastTrustHeartbeatTime

Returns:

  • (String)


2407
2408
2409
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2407

def last_trust_heartbeat_time
  @last_trust_heartbeat_time
end

#selective_authenticationBoolean Also known as: selective_authentication?

Optional. The trust authentication type, which decides whether the trusted side has forest/domain wide access or selective access to an approved set of resources. Corresponds to the JSON property selectiveAuthentication

Returns:

  • (Boolean)


2414
2415
2416
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2414

def selective_authentication
  @selective_authentication
end

#stateString

Output only. The current state of the trust. Corresponds to the JSON property state

Returns:

  • (String)


2420
2421
2422
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2420

def state
  @state
end

#state_descriptionString

Output only. Additional information about the current state of the trust, if available. Corresponds to the JSON property stateDescription

Returns:

  • (String)


2426
2427
2428
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2426

def state_description
  @state_description
end

#target_dns_ip_addressesArray<String>

Required. The target DNS server IP addresses which can resolve the remote domain involved in the trust. Corresponds to the JSON property targetDnsIpAddresses

Returns:

  • (Array<String>)


2432
2433
2434
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2432

def target_dns_ip_addresses
  @target_dns_ip_addresses
end

#target_domain_nameString

Required. The fully qualified target domain name which will be in trust with the current domain. Corresponds to the JSON property targetDomainName

Returns:

  • (String)


2438
2439
2440
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2438

def target_domain_name
  @target_domain_name
end

#trust_directionString

Required. The trust direction, which decides if the current domain is trusted, trusting, or both. Corresponds to the JSON property trustDirection

Returns:

  • (String)


2444
2445
2446
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2444

def trust_direction
  @trust_direction
end

#trust_handshake_secretString

Required. The trust secret used for the handshake with the target domain. This will not be stored. Corresponds to the JSON property trustHandshakeSecret

Returns:

  • (String)


2450
2451
2452
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2450

def trust_handshake_secret
  @trust_handshake_secret
end

#trust_typeString

Required. The type of trust represented by the trust resource. Corresponds to the JSON property trustType

Returns:

  • (String)


2455
2456
2457
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2455

def trust_type
  @trust_type
end

#update_timeString

Output only. The last update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


2460
2461
2462
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2460

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2467

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @last_trust_heartbeat_time = args[:last_trust_heartbeat_time] if args.key?(:last_trust_heartbeat_time)
  @selective_authentication = args[:selective_authentication] if args.key?(:selective_authentication)
  @state = args[:state] if args.key?(:state)
  @state_description = args[:state_description] if args.key?(:state_description)
  @target_dns_ip_addresses = args[:target_dns_ip_addresses] if args.key?(:target_dns_ip_addresses)
  @target_domain_name = args[:target_domain_name] if args.key?(:target_domain_name)
  @trust_direction = args[:trust_direction] if args.key?(:trust_direction)
  @trust_handshake_secret = args[:trust_handshake_secret] if args.key?(:trust_handshake_secret)
  @trust_type = args[:trust_type] if args.key?(:trust_type)
  @update_time = args[:update_time] if args.key?(:update_time)
end