Class: Google::Apis::ManagedidentitiesV1::ValidateTrustRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/managedidentities_v1/classes.rb,
lib/google/apis/managedidentities_v1/representations.rb,
lib/google/apis/managedidentities_v1/representations.rb

Overview

Request message for ValidateTrust

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ValidateTrustRequest

Returns a new instance of ValidateTrustRequest.



2527
2528
2529
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2527

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#trust_propGoogle::Apis::ManagedidentitiesV1::TrustProp

Represents a relationship between two domains. This allows a controller in one domain to authenticate a user in another domain. If the trust is being changed, it will be placed into the UPDATING state, which indicates that the resource is being reconciled. At this point, Get will reflect an intermediate state. Corresponds to the JSON property trust



2525
2526
2527
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2525

def trust_prop
  @trust_prop
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2532
2533
2534
# File 'lib/google/apis/managedidentities_v1/classes.rb', line 2532

def update!(**args)
  @trust_prop = args[:trust_prop] if args.key?(:trust_prop)
end